package com.skywang.control;

import android.os.Bundle;
import android.app.Activity;
import android.view.Menu;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.util.Log;
import android.content.ContentResolver;
import android.net.Uri;

import android.provider.Settings;
import android.provider.Settings.SettingNotFoundException;
import android.view.WindowManager;
public class ButtonTest extends Activity implements View.OnClickListener{
	private static final String TAG = "SKYWANG";

	private Button mButtonPlus  = null;
	private Button mButtonMinus = null;
	
	private int mBrightness = 100;
	
	private static final int MIN_BRIGHTNESS = 10;
	private static final int MAX_BRIGHTNESS = 255;
	private static final int STEP_LEN = 10;
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.button_test);
		
		// 保存原始的亮度值
		mBrightness = getBrightness();
		
		mButtonPlus = (Button)findViewById(R.id.button_plus);
		mButtonPlus.setOnClickListener(this);

		mButtonMinus = (Button)findViewById(R.id.button_minus);
		mButtonMinus.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View v) {
				Log.d(TAG, "click button minus");
				// 减少亮度
				minusBrightness();
			}
		});
	}
	
	@Override
	public void onClick(View v) {
		switch (v.getId()) {
			case R.id.button_plus: {
				Log.d(TAG, "click button plus");
				// 增加亮度
				plusBrightness();
				break;
			}
			default:
				break;
		}
	}
	
	// button_reset的实现函数
	public void clickReset(View v) {
		Log.d(TAG, "click reset");
		setBrightness(mBrightness);
	}
	
	/*
	 * 获取当前亮度值
	 */
    private int getBrightness() {
        int brightness = 0;
        try {
            brightness = Settings.System.getInt(getContentResolver(),
                    Settings.System.SCREEN_BRIGHTNESS);
        } catch (SettingNotFoundException snfe) {
        }   
        return brightness;
    }
    
    /*
     * 设置当前activity的亮度。
     */
    private void setBrightness(int brightness) {
    	WindowManager.LayoutParams lp = getWindow().getAttributes();
        lp.screenBrightness = Float.valueOf(brightness) * (1f / 255f);
        getWindow().setAttributes(lp);
        // 若不保存亮度，退出该activity之后，亮度值会还原。
        saveBrightness(getContentResolver(), brightness);
    }
    
    /*
     * 保存亮度值
     */
    private void saveBrightness(ContentResolver resolver, int brightness) {
        Uri uri = android.provider.Settings.System
                .getUriFor("screen_brightness");
        android.provider.Settings.System.putInt(resolver, "screen_brightness",
                brightness);
        resolver.notifyChange(uri, null);
    }

    /*
     * 增加亮度
     */
    private void plusBrightness() {
		int brightness = getBrightness();
		if (brightness < MAX_BRIGHTNESS) {
			int pre=brightness;			
			brightness += STEP_LEN;
			brightness = brightness<MAX_BRIGHTNESS ? brightness: MAX_BRIGHTNESS;
			setBrightness(brightness);
			Log.d(TAG, "plus brightness : "+pre+"->"+brightness);
		} else {
			Log.d(TAG, "max Brightness!");
		}
	}
    
    /*
     * 减少亮度
     */
    private void minusBrightness() {
		int brightness = getBrightness();
		if (brightness > MIN_BRIGHTNESS) {

			int pre=brightness;
			brightness -= STEP_LEN;
			brightness = brightness>MIN_BRIGHTNESS ? brightness: MIN_BRIGHTNESS;
			setBrightness(brightness);
			Log.d(TAG, "minus brightness : "+pre+"->"+brightness);
		} else {
			Log.d(TAG, "min Brightness!");
		}
	}
    
}
